#
# spec file for package liborigin
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define shlib %{name}3
Name:           liborigin
Version:        3.0.2
Release:        bp156.1.4
Summary:        A library for reading OriginLab OPJ project files
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://sourceforge.net/projects/liborigin/
Source:         http://downloads.sourceforge.net/liborigin/%{name}-%{version}.tar.gz
Source2:        liborigin-rpmlintrc
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
A library for reading OriginLab OPJ project files.
Features:
* reads any worksheets with all columns
* supports 4.1, 5.0, 6.0, 6.1, 7.0, 7.5 projects

%package     -n %{shlib}
Summary:        A library for reading OriginLab OPJ project files
Group:          System/Libraries

%description -n %{shlib}
A library for reading OriginLab OPJ project files.
Features:
* reads any worksheets with all columns
* supports 4.1, 5.0, 6.0, 6.1, 7.0, 7.5 projects

%package        devel
Summary:        Libraries and header files for liborigin
Group:          Development/Libraries/C and C++
Requires:       %{shlib} = %{version}
Recommends:     %{name}-doc

%description    devel
This package contains libraries and header files for developing
applications that read OriginLab OPJ project files.

%package        doc
Summary:        Documentation for liborigin
Group:          Documentation/Other
BuildArch:      noarch

%description    doc
This package provides the documentation for liborigin.

%package        tools
Summary:        Converter for OriginLab OPJ project files
Group:          Productivity/Scientific/Other

%description    tools
Converter for OriginLab OPJ project files.
Features:
* reads any worksheets with all columns
* supports 4.1, 5.0, 6.0, 6.1, 7.0, 7.5 projects

%prep
%autosetup -p1

%build
%cmake \
	-DBUILD_STATIC_LIBS=off \
	-DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name}
%cmake_build origin opj2dat doc

%install
%cmake_install

%post -n %{shlib} -p /sbin/ldconfig
%postun -n %{shlib} -p /sbin/ldconfig

%files -n %{shlib}
%{_libdir}/%{name}.so.*

%files devel
%{_libdir}/%{name}.so
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/*.pc

%files doc
%{_docdir}/%{name}/

%files tools
%{_bindir}/opj2dat

%changelog
* Thu Aug  3 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.2:
  * No news file or changelog from upstream.
* Tue May 18 2021 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.0.1:
  * support 2021bSR0
  * drop liborigin-link-opj2dat-against-sharedlib.patch, included
  * drop liborigin-remove-exit-calls.patch, included upstream
- silence packaging warning for liborigin-tools via rpmlintrc
* Tue Apr 23 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.0:
  * No news file or changelog from upstream.
- Drop liborigin2-nostatic.patch: instead specify build targets
  for make individually, omitting the static lib.
- Add liborigin-link-opj2dat-against-sharedlib.patch: compile
  opj2dat against the shared lib instead of the static lib; patch
  taken from upstream bug report
  (https://sourceforge.net/p/liborigin/bugs/24/).
- Add liborigin-remove-exit-calls.patch: Remove exit calls from
  library; patch taken from upstream git (commit #a8b25b48).
- Update shared lib package name in keeping with upstream so
  versioning bump.
- Use %%%%cmake_build for building and pass individual targets for
  make: origin, opj2dat, and doc.
- Building doc now requires doxygen.
- Drop boost-devel BuildRequires: no longer needed.
- Update sed command to fix location of documentation in keeping
  with changes to upstream CMakelists.txt file.
- Use %%%%autosetup to setup build dir.
- Package pkgconfig file; introduce BuildRequires: pkgconfig to
  auto-generate appropriate pkgconfig-based Provides.
- Drop sed script for libdir, no longer needed.
- Minor cleanups using spec-cleaner.
* Thu Feb 22 2018 jengelh@inai.de
- Fix SRPM group.
* Tue Feb  6 2018 mailaender@opensuse.org
- Update to version 2.0.0
  * No changelog was provided
  Drop liborigin-200080225-gcc.patch
  Add liborigin2-nostatic.patch
* Fri Jun 17 2016 dmitry_r@opensuse.org
- Fix build with GCC6 [boo#985159]
* Sat Feb 16 2013 dmitry_r@opensuse.org
- Update to version 20080225
  * improvements from qtiplot
  * clean up, Excel worksheets
  * fixed crash in 7.0 projects
* Sun Jul  8 2007 leon@links2linux.de
- Initial release.
